Managing timetable and substitution data
========================================

Currently, Chronos does not provide an interface for
interactively managing timetable data.

Instead, data is imported from an external source. The
official distribution handbook contains documentation about
the existing integration apps.

While there is basic support for editing substitutions, the
interface should not be used when substitution data is
imported from an external source.
